//[mahjong-utils](../../../index.md)/[mahjongutils.shanten](../index.md)/[ChitoiShantenResult](index.md)/[ChitoiShantenResult](-chitoi-shanten-result.md)

# ChitoiShantenResult

[common]\
constructor(hand: [Hand](../../mahjongutils.models.hand/-hand/index.md)&lt;[ChitoiHandPattern](../../mahjongutils.models.hand/-chitoi-hand-pattern/index.md)&gt;, shantenInfo: [CommonShanten](../-common-shanten/index.md))
